@@ -3,7 +3,7 @@ use Moose::Role;
 use CatalystX::InjectComponent;
 use namespace::autoclean;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 after 'setup_components' => sub {
     my $class = shift;
@@ -37,14 +37,19 @@ CatalystX::SimpleLogin - Provide a simple Login controller which can be reused
         'Plugin::Authentication' => { # Auth config here }
     );
 
-    __PACKAGE__->setup;
+   __PACKAGE__->config(
+        'Controller::Login' => { # SimpleLogin config here }
+   );
+
+   __PACKAGE__->setup;
 
 =head1 DESCRIPTION
 
 CatalystX::SimpleLogin is an application class L<Moose::Role|role> which will
 inject a L<Catalyst::Controller|controller>
 which is an instance of L<CatalystX::SimpleLogin::Controller::Login> into your
-application. This provides a simple login and logout page with only one line of code.
+application. This provides a simple login and logout page with the adition
+of only one line of code and one template to your application.
 
 =head1 REQUIREMENTS
 
@@ -56,7 +61,7 @@ application. This provides a simple login and logout page with only one line of
 
 =item Working session configuration
 
-=item A TT view
+=item A view
 
 =back
 
@@ -64,9 +69,20 @@ application. This provides a simple login and logout page with only one line of
 
 CatalystX::SimpleLogin is a prototype for CatalystX::Elements. As such, one of the goals
 is to make it easy for users to customise the provided component to the maximum degree
-possible, and also, to main a linear relationship between effort invested and level of
+possible, and also, to have a linear relationship between effort invested and level of
 customisation achieved.
 
+Three traits are shipped with SimpleLogin: WithRedirect, Logout, and RenderAsTTTemplate.
+These traits are set in the config:
+
+   __PACKAGE__->config(
+        'Controller::Login' => {
+            traits => ['Logout', 'WithRedirect', 'RenderAsTTTemplate'],
+            login_form_args => { # see the login form }, 
+   );
+
+   
+
 =head1 COMPONENTS
 
 =over
@@ -81,9 +97,14 @@ logout actions or override methods.
 =item *
 
 L<CatalystX::SimpleLogin::TraitFor::Controller::Logout> - provides the C<logout> action
-and associated methods. you can compose this manually yourself if you want just that
+and associated methods. You can compose this manually yourself if you want just that
 action.
 
+This trait is set by default, but if you set another trait in your config, you
+will have to include it.
+
+B<FIXME> - Get trait merging working..
+
 =item *
 
 L<CatalystX::SimpleLogin::TraitFor::Controller::Login::WithRedirect> - provides the C<login>
@@ -92,6 +113,12 @@ user was previously redirected. Goes hand in hand with L<Catalyst::ActionRole::N
 
 =item *
 
+L<CatalystX::SimpleLogin::TraitFor::Controller::Login::RenderAsTTTemplate> - sets
+the stash variable 'template' to point to a string reference containing the 
+rendered template so that it's not necessary to have a login.tt template file.
+
+=item *
+
 L<CatalystX::SimpleLogin::Form::Login> - the L<HTML::FormHandler> form for the login form.
 
 =item *
@@ -127,30 +154,48 @@ Please feel free to add to or re-arrange this list :)
 
     git://github.com/bobtfish/catalystx-simplelogin.git
 
-Forks and patches are welcome. Please speak to t0m or zby on #catalyst (irc.perl.org)
-if you want to hack on something and need a hand. :)
+Forks and patches are welcome. #formhandler or #catalyst (irc.perl.org)
+are both good places to ask about using or developing this code.
 
 =head1 SEE ALSO
 
 =over
 
-=item L<Catalyst>
+=item *
 
-=item L<Moose> and L<Moose::Role>
+L<Catalyst>
 
-=item L<MooseX::MethodAttributes::Role::Meta::Role>
+=item *
 
-=item L<CatalystX::InjectComponent>
+L<Moose> and L<Moose::Role>
 
-=item L<HTML::FormHandler>
+=item *
 
-=item L<Catalyst::View::TT>
+L<MooseX::MethodAttributes::Role> - Actions compsed from L<Moose::Role|Roles>.
 
-=item L<Catalyst::Plugin::Authentication>
+=item *
 
-=item L<Catalyst::Plugin::Session>
+L<CatalystX::InjectComponent> - Injects the controller class
 
-=item L<Catalyst::Controller::ActionRole>
+=item *
+
+L<HTML::FormHandler> - Generates the login form
+
+=item *
+
+L<Catalyst::Plugin::Authentication> - Responsible for the actual heavy lifting of authenticating the user
+
+=item *
+
+L<Catalyst::Plugin::Session>
+
+=item *
+
+L<Catalyst::Controller::ActionRole> - Allows you to decorate actions with roles (E.g L<Catalyst::ActionRole::NeedsLogin|To force a redirect to the login page>)
+
+=item *
+
+L<CatalystX::Component::Traits> - Allows L<Moose::Role|roles> to be composed onto components from config
 
 =back
 
